//
// Copyright (c) 2004 - InfoMus Lab - DIST - University of Genova
//
// InfoMus Lab (Laboratorio di Informatica Musicale)
// DIST - University of Genova
//
// http://www.infomus.dist.unige.it
// news://infomus.dist.unige.it
// mailto:staff@infomus.dist.unige.it
//
// Developer: Gualtiero Volpe
// mailto:volpe@infomus.dist.unige.it
//
// Last modified: 2004-11-10
//
// 2019-07-22 ffgl@subpixels.com
// - use enum PluginType

#include "PluginInfo.h"
#include <assert.h>
#include <stdlib.h>
#include <memory.h>
#include "Utils.h"

namespace ffgl
{
extern PluginInfo* g_CurrPluginInfo;

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// PluginInfo constructor and destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

PluginInfo::PluginInfo(
	FPCREATEINSTANCEGL* createInstance,
	const std::string& uniqueID,
	const std::string& pluginName,
	FFUInt32 apiMajorVersion,
	FFUInt32 apiMinorVersion,
	FFUInt32 pluginMajorVersion,
	FFUInt32 pluginMinorVersion,
	PluginType pluginType,
	const std::string& description,
	const std::string& about,
	FFUInt32 freeFrameExtendedDataSize,
	const void* freeFrameExtendedDataBlock ) :

	createInstance( createInstance ),
	basicInfo( apiMajorVersion, apiMinorVersion, uniqueID, pluginName, pluginType ),
	extendedInfo( pluginMajorVersion, pluginMinorVersion, description, about, freeFrameExtendedDataSize, freeFrameExtendedDataBlock )
{
	// This FFGL SDK is intended for developing plugins based on the FFGL 2.0 specification. Please
	// Update your plugin code to use FFGL 2.0.
	assert( apiMajorVersion >= 2 );

	// Global handle to the plugin info
	g_CurrPluginInfo = this;
}

PluginInfo::~PluginInfo()
{
	free( extendedInfo.About );
	free( extendedInfo.Description );
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// PluginInfo methods
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

const GetPluginInfoStruct* PluginInfo::GetPluginInfo() const
{
	return &basicInfo;
}

const GetPluginExtendedInfoStruct* PluginInfo::GetPluginExtendedInfo() const
{
	return &extendedInfo;
}

FPCREATEINSTANCEGL* PluginInfo::GetFactoryMethod() const
{
	return createInstance;
}

}//End namespace ffgl
